@@ -22,6 +22,9 @@ from zope.component import getMultiAdapter
 from Acquisition import aq_inner, aq_parent
 from ZTUtils import make_query
 
+from plone.i18n.normalizer.interfaces import IIDNormalizer
+from zope.component import queryUtility
+
 from z3c.form import form, field, button, group
 from plone.app.z3cform.layout import wrap_form
 from plonetheme.arnolfini.interfaces import IWeekDayContent
@@ -139,7 +142,10 @@ class CommonBrowserView(BrowserView):
                 lead = None
             
         if lead is not None:
+            if hasattr(item, 'getURL'):
                 return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title}
+            else:
+                return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title()}
         else:
             return ""
 
@@ -194,24 +200,33 @@ class CommonBrowserView(BrowserView):
         """
         Gets all the manually related content both related items of the current context and items where the current context is marked as related.
         """
+        filtered = []
         related = []
         related = self.context.getRefs()
         backRelated = self.context.getBRefs()
         
         related.extend(backRelated)
         
-        return self._uniq(related);
+        result = self._uniq(related);
+        
+        for res in result:
+            if self.checkPermission(res, 'View'):
+                filtered.append(res)
+                
+        return filtered
         
     def getContentAsLinks(self, content):
         """
-        A commodity, this formats a content list content as an HTML structure of titles with links. Comma separated. Used to list the artists related to an exhibition.
+        A commodity, this formats a content list as an HTML structure of titles with links. Comma separated. Used to list the artists related to an exhibition.
         """
         result = []
+        workflow = getToolByName(self.context,'portal_workflow')
         for res in content:
-            if res.portal_type == 'Media Person':
-                result.append('<a href="%(link)s">%(title)s</a>'%{'link':res.absolute_url(), 'title':self._normalizePersonName(res.title)})
-            else:
-                result.append('<a href="%(link)s">%(title)s</a>'%{'link':res.absolute_url(), 'title':res.title})               
+            if self.checkPermission(res, 'View'):
+                if res.portal_type == 'Media Person':
+                    result.append('<a href="%(link)s" class="%(state_class)s">%(title)s</a>'%{'link':res.absolute_url(), 'title':self._normalizePersonName(res.title), 'state_class': 'state-' + queryUtility(IIDNormalizer).normalize(workflow.getInfoFor(res,'review_state'))})
+                else:
+                    result.append('<a href="%(link)s" class="%(state_class)s">%(title)s</a>'%{'link':res.absolute_url(), 'title':res.title, 'state_class': 'state-' + queryUtility(IIDNormalizer).normalize(workflow.getInfoFor(res,'review_state'))})               
         
         return ", ".join(result)
     
